# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,censored_sample)
S3method(as.vector,censored_sample)
S3method(print,censored_sample)
S3method(print,dist_spec)
export(dist_spec)
export(plot_censor_acf)
export(plot_censor_diagnostics)
export(plot_censor_dot)
export(plot_censor_hist)
export(r_bjpt2_censor)
export(r_block_random_censor)
export(r_complete)
export(r_doubly_type2_censor)
export(r_hybrid_censor)
export(r_hybrid_type1_censor)
export(r_hybrid_type2_censor)
export(r_interval_censor)
export(r_joint_type1_censor)
export(r_joint_type2_censor)
export(r_left_censor)
export(r_left_truncation)
export(r_middle_censor)
export(r_progressive_first_failure)
export(r_progressive_hybrid_type2_censor)
export(r_progressive_type2_censor)
export(r_random_censor)
export(r_right_censor)
export(r_right_truncation)
export(r_type1_censor)
export(r_type1_hybrid_censor)
export(r_type2_censor)
importFrom(graphics,abline)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(stats,acf)
importFrom(stats,integrate)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rexp)
importFrom(stats,runif)
importFrom(stats,uniroot)
