% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dist_spec.R
\name{print.censored_sample}
\alias{print.censored_sample}
\title{Print method for censored_sample}
\usage{
\method{print}{censored_sample}(x, ...)
}
\arguments{
\item{x}{a \code{censored_sample} object.}

\item{...}{ignored.}
}
\value{
Invisibly, the input \code{censored_sample} object \code{x}.
Called for its side effect of printing the censoring scheme, distribution
name, sample size, seed, and a frequency table of status codes.
}
\description{
Print method for censored_sample
}
