% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dist_spec.R
\name{as.vector.censored_sample}
\alias{as.vector.censored_sample}
\title{Extract observed values from a censored sample}
\usage{
\method{as.vector}{censored_sample}(x, ...)
}
\arguments{
\item{x}{a \code{censored_sample} object.}

\item{...}{ignored.}
}
\value{
Numeric vector of observed values (failures and censoring times).
}
\description{
Extract observed values from a censored sample
}
