% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dist_spec.R
\name{print.dist_spec}
\alias{print.dist_spec}
\title{Print method for dist_spec}
\usage{
\method{print}{dist_spec}(x, ...)
}
\arguments{
\item{x}{a \code{dist_spec} object.}

\item{...}{ignored.}
}
\value{
Invisibly, the input \code{dist_spec} object \code{x}.  Called
for its side effect of printing a human-readable summary of the
distribution name, support, parameters, and available functions.
}
\description{
Print method for dist_spec
}
